==> nomachine-8.2.3-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/Common/NXImage.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub Common::NXImage::import{package Common::NXImage;no warnings;(my $source=
shift (@_));(my $destination=shift (@_));(my $tempDestination=($destination.
"\x2e\x70\x61\x72\x74"));if ((__import ($source,$tempDestination)<
(0x00f8+ 6775-0x1b6f))){return ((0x12fc+ 2709-0x1d91));}if ((not (rename (
$tempDestination,$destination)))){Logger::warning (((((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6e\x61\x6d\x65\x20\x66\x69\x6c\x65\x20\x27"
.$tempDestination)."\x27\x20\x74\x6f\x20\x27").$destination).
"\x27\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x20").$!)."\x2e"));if ((not (
unlink ($tempDestination)))){Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x75\x6e\x6c\x69\x6e\x6b\x20\x66\x69\x6c\x65\x20".
$tempDestination)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$!)."\x2e"));}
return ((0x00cf+ 2944-0x0c4f));}return ((0x05bd+ 8530-0x270e));}sub 
Common::NXImage::delete{package Common::NXImage;no warnings;(my $path=shift (@_)
);Logger::debug (((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x44\x65\x6c\x65\x74\x65\x28"
.$path)."\x29"));(my $return=libnxhc::NXImageDelete ($path));Logger::debug ((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x44\x65\x6c\x65\x74\x65\x28"
.$path)."\x29\x20\x72\x65\x74\x75\x72\x6e\x20").$return));if (($return<
(0x0819+ 2356-0x114d))){(my $errorNumber=libnxh::NXShellGetError ());(my $errorString
=libnxh::NXGetSystemErrorString ($errorNumber));Logger::warning (((((
"\x43\x6f\x75\x6c\x64\x6e\x27\x74\x20\x64\x65\x6c\x65\x74\x65\x20\x69\x6d\x61\x67\x65\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20").$errorString)."\x2e"));}return ($return);}sub 
Common::NXImage::list{package Common::NXImage;no warnings;(my $path=shift (@_));
Logger::debug (((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x4c\x69\x73\x74\x28"
.$path)."\x29"));(my $buffer=libnxhc::NXImageList ($path));Logger::debug ((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x4c\x69\x73\x74\x28"
.$path)."\x29\x20\x72\x65\x74\x75\x72\x6e\x20").$buffer));(my (@files)=());if (
defined ($buffer)){(@files=split ( /\n/ ,$buffer,(0x0cab+ 3331-0x19ae)));}return
 (@files);}sub Common::NXImage::isoCreate{package Common::NXImage;no warnings;(my $output
=shift (@_));(my $input=shift (@_));(my $label=shift (@_));(my $joliet=shift (@_
));Logger::debug (((((((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x73\x6f\x43\x72\x65\x61\x74\x65\x28"
.$output)."\x2c\x20").$input)."\x2c\x20").$label)."\x2c\x20").$joliet)."\x29"));
(my $return=libnxhc::NXIsoCreate ($output,$input,$label,$joliet));Logger::debug 
(((((((((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x73\x6f\x43\x72\x65\x61\x74\x65\x28"
.$output)."\x2c\x20").$input)."\x2c\x20").$label)."\x2c\x20").$joliet).
"\x29\x20\x72\x65\x74\x75\x72\x6e\x20").$return)."\x2e"));if (($return==
(0x0c19+ 1678-0x12a7))){(my $errorNumber=NXPL::NXShellGetError ());(my $errorString
=NXPL::NXGetSystemErrorString ($errorNumber));Logger::error (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x63\x72\x65\x61\x74\x65\x20\x49\x53\x4f\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20").$errorString)."\x2e"));}return ($return);}sub 
Common::NXImage::replace{package Common::NXImage;no warnings;(my $source=shift (
@_));(my $destination=shift (@_));(my $tempDestination=($destination.
"\x2e\x70\x61\x72\x74"));if ((__import ($source,$tempDestination)<
(0x0765+ 1630-0x0dc3))){return ((0x15e5+ 3774-0x24a3));}if ((not (unlink (
$destination)))){Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x75\x6e\x6c\x69\x6e\x6b\x20\x66\x69\x6c\x65\x20".
$destination)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$!)."\x2e"));if ((
not (unlink ($tempDestination)))){Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x75\x6e\x6c\x69\x6e\x6b\x20\x66\x69\x6c\x65\x20".
$tempDestination)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$!)."\x2e"));}
return ((0x210d+ 1507-0x26f0));}if ((not (rename ($tempDestination,$destination)
))){Logger::warning (((((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6e\x61\x6d\x65\x20\x66\x69\x6c\x65\x20\x27"
.$tempDestination)."\x27\x20\x74\x6f\x20\x27").$destination).
"\x27\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x20").$!)."\x2e"));if ((not (
unlink ($tempDestination)))){Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x75\x6e\x6c\x69\x6e\x6b\x20\x66\x69\x6c\x65\x20".
$tempDestination)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$!)."\x2e"));}
return ((0x0591+ 1361-0x0ae2));}return ((0x0b53+ 2486-0x1508));}sub 
Common::NXImage::__import{package Common::NXImage;no warnings;(my $source=shift 
(@_));(my $destination=shift (@_));Logger::debug (((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x49\x6d\x70\x6f\x72\x74\x28"
.$source)."\x2c\x20").$destination)."\x29"));(my $return=libnxhc::NXImageImport 
($source,$destination));Logger::debug ((((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x49\x6d\x70\x6f\x72\x74\x28"
.$source)."\x2c\x20").$destination)."\x29\x20\x72\x65\x74\x75\x72\x6e\x20").
$return));if (($return<(0x03ac+ 1400-0x0924))){(my $errorNumber=
libnxh::NXShellGetError ());(my $errorString=libnxh::NXGetSystemErrorString (
$errorNumber));Logger::warning (((((
"\x43\x6f\x75\x6c\x64\x6e\x27\x74\x20\x69\x6d\x70\x6f\x72\x74\x20\x69\x6d\x61\x67\x65\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20").$errorString)."\x2e"));if (Common::NXFile::isExists (
$destination)){if ((not (unlink ($destination)))){Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x75\x6e\x6c\x69\x6e\x6b\x20\x66\x69\x6c\x65\x20".
$destination)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$!)."\x2e"));}}}
return ($return);}package Common::NXImage;no warnings;"\x3f\x3f\x3f";

==> nomachine-8.7.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxnode/Common/NXImage.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2023 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXNODE, NX protocol compression and NX extensions to this software      #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub Common::NXImage::import{package Common::NXImage;no warnings;(my $source=
shift (@_));(my $destination=shift (@_));(my $tempDestination=($destination.
"\x2e\x70\x61\x72\x74"));if ((__import ($source,$tempDestination)<
(0x1120+ 2984-0x1cc8))){return ((0x0159+ 8553-0x22c2));}if ((not (rename (
$tempDestination,$destination)))){Logger::warning (((((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6e\x61\x6d\x65\x20\x66\x69\x6c\x65\x20\x27"
.$tempDestination)."\x27\x20\x74\x6f\x20\x27").$destination).
"\x27\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x20").$!)."\x2e"));if ((not (
unlink ($tempDestination)))){Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x75\x6e\x6c\x69\x6e\x6b\x20\x66\x69\x6c\x65\x20".
$tempDestination)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$!)."\x2e"));}
return ((0x00ff+ 5318-0x15c5));}return ((0x069c+ 3060-0x128f));}sub 
Common::NXImage::delete{package Common::NXImage;no warnings;(my $path=shift (@_)
);Logger::debug (((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x44\x65\x6c\x65\x74\x65\x28"
.$path)."\x29"));(my $return=libnxhc::NXImageDelete ($path));Logger::debug ((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x44\x65\x6c\x65\x74\x65\x28"
.$path)."\x29\x20\x72\x65\x74\x75\x72\x6e\x20").$return));if (($return<
(0x0e16+ 5759-0x2495))){(my $errorNumber=libnxh::NXShellGetError ());(my $errorString
=libnxh::NXGetSystemErrorString ($errorNumber));Logger::warning (((((
"\x43\x6f\x75\x6c\x64\x6e\x27\x74\x20\x64\x65\x6c\x65\x74\x65\x20\x69\x6d\x61\x67\x65\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20").$errorString)."\x2e"));}return ($return);}sub 
Common::NXImage::list{package Common::NXImage;no warnings;(my $path=shift (@_));
Logger::debug (((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x4c\x69\x73\x74\x28"
.$path)."\x29"));(my $buffer=libnxhc::NXImageList ($path));Logger::debug ((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x4c\x69\x73\x74\x28"
.$path)."\x29\x20\x72\x65\x74\x75\x72\x6e\x20").$buffer));(my (@files)=());if (
defined ($buffer)){(@files=split ( /\n/ ,$buffer,(0x04e8+ 1573-0x0b0d)));}return
 (@files);}sub Common::NXImage::isoCreate{package Common::NXImage;no warnings;(my $output
=shift (@_));(my $input=shift (@_));(my $label=shift (@_));(my $joliet=shift (@_
));Logger::debug (((((((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x73\x6f\x43\x72\x65\x61\x74\x65\x28"
.$output)."\x2c\x20").$input)."\x2c\x20").$label)."\x2c\x20").$joliet)."\x29"));
(my $return=libnxhc::NXIsoCreate ($output,$input,$label,$joliet));Logger::debug 
(((((((((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x73\x6f\x43\x72\x65\x61\x74\x65\x28"
.$output)."\x2c\x20").$input)."\x2c\x20").$label)."\x2c\x20").$joliet).
"\x29\x20\x72\x65\x74\x75\x72\x6e\x20").$return)."\x2e"));if (($return==
(0x053c+ 706-0x07fe))){(my $errorNumber=NXPL::NXShellGetError ());(my $errorString
=NXPL::NXGetSystemErrorString ($errorNumber));Logger::error (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x63\x72\x65\x61\x74\x65\x20\x49\x53\x4f\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20").$errorString)."\x2e"));}return ($return);}sub 
Common::NXImage::replace{package Common::NXImage;no warnings;(my $source=shift (
@_));(my $destination=shift (@_));(my $tempDestination=($destination.
"\x2e\x70\x61\x72\x74"));if ((__import ($source,$tempDestination)<
(0x0220+ 269-0x032d))){return ((0x0514+ 2628-0x0f58));}if ((not (unlink (
$destination)))){Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x75\x6e\x6c\x69\x6e\x6b\x20\x66\x69\x6c\x65\x20".
$destination)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$!)."\x2e"));if ((
not (unlink ($tempDestination)))){Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x75\x6e\x6c\x69\x6e\x6b\x20\x66\x69\x6c\x65\x20".
$tempDestination)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$!)."\x2e"));}
return ((0x1039+ 5799-0x26e0));}if ((not (rename ($tempDestination,$destination)
))){Logger::warning (((((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x6e\x61\x6d\x65\x20\x66\x69\x6c\x65\x20\x27"
.$tempDestination)."\x27\x20\x74\x6f\x20\x27").$destination).
"\x27\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20\x20").$!)."\x2e"));if ((not (
unlink ($tempDestination)))){Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x75\x6e\x6c\x69\x6e\x6b\x20\x66\x69\x6c\x65\x20".
$tempDestination)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$!)."\x2e"));}
return ((0x114b+ 2419-0x1abe));}return ((0x0e09+ 1495-0x13df));}sub 
Common::NXImage::__import{package Common::NXImage;no warnings;(my $source=shift 
(@_));(my $destination=shift (@_));Logger::debug (((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x49\x6d\x70\x6f\x72\x74\x28"
.$source)."\x2c\x20").$destination)."\x29"));(my $return=libnxhc::NXImageImport 
($source,$destination));Logger::debug ((((((
"\x6c\x69\x62\x6e\x78\x68\x63\x3a\x3a\x4e\x58\x49\x6d\x61\x67\x65\x49\x6d\x70\x6f\x72\x74\x28"
.$source)."\x2c\x20").$destination)."\x29\x20\x72\x65\x74\x75\x72\x6e\x20").
$return));if (($return<(0x03c9+ 5215-0x1828))){(my $errorNumber=
libnxh::NXShellGetError ());(my $errorString=libnxh::NXGetSystemErrorString (
$errorNumber));Logger::warning (((((
"\x43\x6f\x75\x6c\x64\x6e\x27\x74\x20\x69\x6d\x70\x6f\x72\x74\x20\x69\x6d\x61\x67\x65\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20"
.$errorNumber)."\x2c\x20").$errorString)."\x2e"));if (Common::NXFile::isExists (
$destination)){if ((not (unlink ($destination)))){Logger::warning (((((
"\x43\x61\x6e\x6e\x6f\x74\x20\x75\x6e\x6c\x69\x6e\x6b\x20\x66\x69\x6c\x65\x20".
$destination)."\x2e\x20\x45\x72\x72\x6f\x72\x20\x69\x73\x20").$!)."\x2e"));}}}
return ($return);}package Common::NXImage;no warnings;"\x3f\x3f\x3f";
